==> nextcloud-27.1.1p0.tgz: nextcloud/apps/files_reminders/l10n/sr.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Подсетници о фајлу",
    "Reminder for {name}" : "Подсетник за {name}",
    "View file" : "Погледај фајл",
    "View folder" : "Погледај фолдер",
    "Set file reminders" : "Постави подсетнике о фајлу",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Подсетници о фајлу**\n\nПостављање подсетника о фајлу.",
    "Back" : "Назад",
    "Clear reminder" : "Обриши подсетник",
    "Set custom reminder" : "Постави произвољни подсетник",
    "Later today" : "Касније данас",
    "Set reminder for later today" : "Поставља подсетник за касније данас",
    "Tomorrow" : "Сутра",
    "Set reminder for tomorrow" : "Поставља подсетник за сутра",
    "This weekend" : "Овог викенда",
    "Set reminder for this weekend" : "Поставља подсетник за овај викенд",
    "Next week" : "Наредне недеље",
    "Set reminder for next week" : "Поставља подсетник за наредну недељу",
    "Set reminder at custom date & time" : "Постави подсетник за произвољни датум и време",
    "Reminder set for \"{fileName}\"" : "Подсетник је постављен за „{fileName}”",
    "Failed to set reminder" : "Није успело постављање подсетника",
    "Please choose a valid date & time" : "Молимо вас да изаберете исправни датум и време",
    "Reminder cleared" : "Подсетник је обрисан",
    "Failed to clear reminder" : "Није успело брисање подсетника",
    "Failed to load reminder" : "Није успело учитавање подсетника"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/files_reminders/l10n/sr.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Подсетници о фајлу",
    "Reminder for {name}" : "Подсетник за {name}",
    "View file" : "Погледај фајл",
    "View folder" : "Погледај фолдер",
    "Set file reminders" : "Постави подсетнике о фајлу",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Подсетници о фајлу**\n\nПостављање подсетника о фајлу.",
    "We will remind you of this file" : "Подсетићемо вас на овај фајл",
    "Please choose a valid date & time" : "Молимо вас да изаберете исправни датум и време",
    "Cancel" : "Откажи",
    "Set reminder" : "Постави подсетник",
    "Set reminder for \"{fileName}\"" : "Постави подсетник за „{fileName}”",
    "Set reminder at custom date & time" : "Постави подсетник за произвољни датум и време",
    "Clear reminder" : "Обриши подсетник",
    "Reminder set for \"{fileName}\"" : "Подсетник је постављен за „{fileName}”",
    "Failed to set reminder" : "Није успело постављање подсетника",
    "Set custom reminder" : "Постави произвољни подсетник",
    "Later today" : "Касније данас",
    "Set reminder for later today" : "Поставља подсетник за касније данас",
    "Tomorrow" : "Сутра",
    "Set reminder for tomorrow" : "Поставља подсетник за сутра",
    "This weekend" : "Овог викенда",
    "Set reminder for this weekend" : "Поставља подсетник за овај викенд",
    "Next week" : "Наредне недеље",
    "Set reminder for next week" : "Поставља подсетник за наредну недељу",
    "Back" : "Назад",
    "Reminder cleared" : "Подсетник је обрисан",
    "Failed to clear reminder" : "Није успело брисање подсетника",
    "Failed to load reminder" : "Није успело учитавање подсетника"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
